<?php

/**
 * @file
 * Admin page callbacks for the cookiless subdomain module.
 */

/**
 * Page generation function for admin/settings/cookieless_subdomain
 */
function cookieless_subdomain_admin_page() {
  $output = '';
  return $output . drupal_get_form('cookieless_subdomain_admin_settings_form');
}

/**
 * Form builder; Configure advagg settings.
 *
 * @ingroup forms
 * @see system_settings_form()
 */
function cookieless_subdomain_admin_settings_form() {
  $form = array();

  $form['cookieless_subdomains'] = array(
    '#type'           => 'textarea',
    '#title'          => t('Cookieless subdomains'),
    '#default_value'  => implode("\n", variable_get('cookieless_subdomains', array())),
    '#description'    => t('Specify a list of subdomains, one per line. Make sure that all the speficied domains can serve the files that get stored in the files directory under the same path as the main domain.'),
  );

  $form['cookieless_subdomains_domain'] = array(
    '#type'           => 'textfield',
    '#title'          => t('Domain'),
    '#default_value'  => variable_get('cookieless_subdomains_domain', array()),
    '#description'    => t('Specify the domain to use. If you leave this empty, the usual domain of your website will be used.'),
  );

  return system_settings_form($form);
}

/**
 * Validate form values. Used to transform variables before they get saved.
 *
 * We do not invalidate any cached items when the number or name of the subdomains change.
 * Do to the coherent hashing this is not neccessary. Cache keys will change as needed.
 */
function cookieless_subdomain_admin_settings_form_validate($form, &$form_state) {

  $values = explode("\n", str_replace("\r", '', (trim($form_state['values']['cookieless_subdomains']))));

  $unique_values = array_unique($values);
  if (count($unique_values) != count($values)) {
    form_set_error('cookieless_subdomains', t('You need to define distinct subdomains.'));
  }

  $form_state['values']['cookieless_subdomains'] = $values;
}

